#!/usr/bin/python
# -*- coding: UTF-8 -*-
 

import os



#非递归
def search_file_indir_with_ext(dirname, fileExts):

	result = 	[]#所有的文件
	
	items = os.listdir(dirname);

	for i in range(0,len(items)):
		path = os.path.join(dirname, items[i])
		if os.path.isfile(path):
			ext = os.path.splitext(path)[1]
			if ext in fileExts:
				result.append(path)
	return result

#递归
def search_file_recur_indir_with_ext(dirname, fileExts):

    result = []#所有的文件
    for maindir, subdir, file_name_list in os.walk(dirname):
		for filename in file_name_list:
			path = os.path.join(maindir, filename) #合并成一个完整路径
			ext = os.path.splitext(path)[1]  # 获取文件后缀 [0]获取的是除了文件名以外的内容
			if ext in fileExts:
				result.append(path)
    return result


#非递归
def search_dir_indir(dirname):

	result = []#所有的文件

	items = os.listdir(dirname);
	for i in range(0,len(items)):
		path = os.path.join(dirname,items[i])
		if os.path.isdir(path):
			result.append(path)

	return result




"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

from setuptools import setup, find_packages
from os import path
from io import open

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(

    name='ochelper',  # Required

    version='0.0.4',  

    description='ochelper for objective-c',

    long_description=long_description, 

    long_description_content_type='text/markdown', 

    url='https://github.com',  # Optional

    author='weishqdev',  

    author_email="weishqdev@gmail.com",

    classifiers=[  # Optional
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],


    keywords='objective-c code proc',  # Optional

    packages=find_packages(exclude=['contrib', 'docs', 'tests']),  # Required

    install_requires=[], 

    # extras_require={  # Optional
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },

    # data_files=[('my_data', ['data/data_file'])],  # Optional

    entry_points = {
        'console_scripts': [
              'ochelper = ochelper.ochelper:main'
        ]
    }

)



#!/usr/bin/python
# -*- coding: UTF-8 -*-
 
import os;
import sys;
import argparse;

from .ochandler import ochandler;


project_dir = "/Users/wade/Documents/codingapp/LiteGZ" # 字符串

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('-p', '--path', help="需要处理的代码路径")
    parser.add_argument('-o', '--out', help="输出的路径")
    args = parser.parse_args()

    project_dir = os.getcwd()
    if args.path != None:
        project_dir = args.path
    print project_dir

    output_dir = os.getcwd()
    if args.out != None:
        output_dir = args.out
    print output_dir
    ochandler(project_dir, output_dir)


if __name__ == "__main__":
    main()
